CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
64 lines
2.6 KiB
Common Lisp
64 lines
2.6 KiB
Common Lisp
// RUN: %clang_cc1 -emit-llvm -o - -O0 -triple spir-unknown-unknown -cl-std=CL1.2 -finclude-default-header %s \
|
|
// RUN: | FileCheck %s --check-prefixes CHECK,CHECK-NOGAS
|
|
// RUN: %clang_cc1 -emit-llvm -o - -O0 -triple spir-unknown-unknown -cl-std=CL1.2 -fdeclare-opencl-builtins -finclude-default-header %s \
|
|
// RUN: | FileCheck %s --check-prefixes CHECK,CHECK-NOGAS
|
|
// RUN: %clang_cc1 -emit-llvm -o - -O0 -triple spir-unknown-unknown -cl-std=CL3.0 -fdeclare-opencl-builtins -finclude-default-header %s \
|
|
// RUN: | FileCheck %s --check-prefixes CHECK,CHECK-GAS
|
|
// RUN: %clang_cc1 -emit-llvm -o - -O0 -triple spir-unknown-unknown -cl-std=CL3.0 -fdeclare-opencl-builtins -finclude-default-header \
|
|
// RUN: -cl-ext=-__opencl_c_generic_address_space,-__opencl_c_pipes,-__opencl_c_device_enqueue %s \
|
|
// RUN: | FileCheck %s --check-prefixes CHECK,CHECK-NOGAS
|
|
|
|
// Test that mix is correctly defined.
|
|
// CHECK-LABEL: @test_float
|
|
// CHECK: call spir_func <4 x float> @_Z3mixDv4_fS_f
|
|
// CHECK: ret
|
|
void test_float(float4 x, float a) {
|
|
float4 ret = mix(x, x, a);
|
|
}
|
|
|
|
// Test that Attr.Const from OpenCLBuiltins.td is lowered to a readnone attribute.
|
|
// CHECK-LABEL: @test_const_attr
|
|
// CHECK: call spir_func i32 @_Z3maxii({{.*}}) [[ATTR_CONST:#[0-9]]]
|
|
// CHECK: ret
|
|
int test_const_attr(int a) {
|
|
return max(a, 2);
|
|
}
|
|
|
|
// Test that Attr.Pure from OpenCLBuiltins.td is lowered to a readonly attribute.
|
|
// CHECK-LABEL: @test_pure_attr
|
|
// CHECK: call spir_func <4 x float> @_Z11read_imagef{{.*}} [[ATTR_PURE:#[0-9]]]
|
|
// CHECK: ret
|
|
kernel void test_pure_attr(read_only image1d_t img) {
|
|
float4 resf = read_imagef(img, 42);
|
|
}
|
|
|
|
// Test that builtins with only one prototype are mangled.
|
|
// CHECK-LABEL: @test_mangling
|
|
// CHECK: call spir_func i32 @_Z12get_local_idj
|
|
kernel void test_mangling() {
|
|
size_t lid = get_local_id(0);
|
|
}
|
|
|
|
// Test that the correct builtin is called depending on the generic address
|
|
// space feature availability.
|
|
// CHECK-LABEL: @test_generic_optionality
|
|
// CHECK-GAS: call spir_func float @_Z5fractfPU3AS4f
|
|
// CHECK-NOGAS: call spir_func float @_Z5fractfPf
|
|
void test_generic_optionality(float a, float *b) {
|
|
float res = fract(a, b);
|
|
}
|
|
|
|
// Test that the correct builtin is called depending on the generic address
|
|
// space feature availability. If not available, the __private version is called
|
|
// CHECK-LABEL: @test_wait_group_events
|
|
// CHECK-GAS: call spir_func void @_Z17wait_group_eventsiPU3AS49ocl_event
|
|
// CHECK-NOGAS: call spir_func void @_Z17wait_group_eventsiP9ocl_event
|
|
void test_wait_group_events(int i, event_t *e) {
|
|
wait_group_events(i, e);
|
|
}
|
|
|
|
// CHECK: attributes [[ATTR_CONST]] =
|
|
// CHECK-SAME: memory(none)
|
|
// CHECK: attributes [[ATTR_PURE]] =
|
|
// CHECK-SAME: memory(read)
|